pub struct Guard<'guard> { /* private fields */ }Expand description
When a Guard is dropped, it will stop recording the
event of the inner profiler.
If profiling is disabled, the Guard struct will do nothing.